@@ -39,6 +39,7 @@ from os import PathLike
 from typing import Union, Optional, TYPE_CHECKING, ClassVar, Tuple, List, Callable, overload, Any, Type, TypeVar
 
 from . import utils
+from .object import Object
 from .error import HTTPException
 from .file import File
 from .member import Member
@@ -53,10 +54,15 @@ from .reaction import Reaction
 if TYPE_CHECKING:
     from .state import ConnectionState
     from .abc import GuildChannel, PartialMessageableChannel, MessageableChannel
-    from .channel import TextChannel
+    from .channel import TextChannel, DMChannel
     from .enum import ChannelType
-    from .types.message import Attachment as AttachmentPayload, Message as MessagePayload, \
-        MessageReference as MessageReferencePayload, Reaction as ReactionPayload
+    from .types.message import (
+        Attachment as AttachmentPayload,
+        Message as MessagePayload,
+        MessageReference as MessageReferencePayload,
+        Reaction as ReactionPayload,
+        MessageAudit as MessageAuditPayload
+    )
     from .types.embed import Embed as EmbedPayload
     from .types.user import User as UserPayload
     from .types.member import Member as MemberPayload, UserWithMember as UserWithMemberPayload
@@ -70,9 +76,91 @@ __all__ = (
     'Message',
     'PartialMessage',
     'MessageReference',
+    'MessageAudit'
 )
 
 
+class MessageAudit:
+    """表示消息审核情况。
+
+    .. container:: operations
+
+        .. describe:: x == y
+
+            检查两个审核是否相等。
+
+        .. describe:: x != y
+
+            检查两个审核是否不相等。
+
+    Attributes
+    -----------
+    id: :class:`str`
+        审核的 ID 。
+    message_id: Optional[:class:`str`]
+        消息 ID，只有审核通过事件才会有值。
+    audit_time: :class:`datetime.datetime`
+        消息审核时间
+    create_time: :class:`datetime.datetime`
+        消息创建时间
+    channel_id: :class:`int`
+        审核消息的子频道 ID
+    guild_id: :class:`str`
+        审核消息的频道 ID
+    """
+
+    __slots__ = (
+        '_state',
+        'id',
+        'message_id',
+        'guild_id',
+        'channel_id',
+        'audit_time',
+        'create_time',
+        '_audit_state'
+    )
+
+    def __init__(self, state: ConnectionState, data: MessageAuditPayload, audit_state):
+        self.id: str = data['audit_id']
+        self._state = state
+        self.message_id: Optional[str] = data.get('message_id')
+        self.channel_id: int = int(data['channel_id'])
+        self.guild_id: int = int(data['guild_id'])
+        self.audit_time: Optional[datetime.datetime] = utils.parse_time(data.get('audit_time'))
+        self.create_time: datetime.datetime = utils.parse_time(data['create_time'])
+        self._audit_state = audit_state
+
+    def __repr__(self) -> str:
+        name = self.__class__.__name__
+        return (
+            f'<{name} id={self.id}>'
+        )
+
+    def __eq__(self, other: Any) -> bool:
+        return isinstance(other, MessageAudit) and self.id == other.id
+
+    def __ne__(self, other: Any) -> bool:
+        return isinstance(other, MessageAudit) and self.id != other.id
+
+    @property
+    def passed(self):
+        """:class:`bool`: 返回消息是否通过审核
+        """
+        return True is self._audit_state is True
+
+    @property
+    def rejected(self):
+        """:class:`bool`: 返回消息是否没通过审核
+        """
+        return True is self._audit_state is False
+
+    @property
+    def pending(self):
+        """:class:`bool`: 返回消息是否正在审核
+        """
+        return True is self._audit_state is None
+
+
 class DeletedReferencedMessage:
     """一种特殊的标记类型，表示已解析的消息引用的消息是否已被删除。
     此类的目的是将无法获取的引用消息与先前获取但已被删除的消息分开。
@@ -409,6 +497,8 @@ class Message(Hashable):
         提供给消息的附件列表。
     guild: Optional[:class:`Guild`]
         消息所属的频道（如果适用）。
+    direct: :class:`bool`
+        是否是私聊消息
     """
     __slots__ = (
         '_state',
@@ -431,7 +521,8 @@ class Message(Hashable):
         'reference',
         'role_mentions',
         'created_at',
-        'reactions'
+        'reactions',
+        'direct'
     )
 
     if TYPE_CHECKING:
@@ -448,7 +539,9 @@ class Message(Hashable):
             state: ConnectionState,
             channel: MessageableChannel,
             data: MessagePayload,
+            direct: bool = False
     ):
+        self.direct = direct
         self._state: ConnectionState = state
         self.created_at = datetime.datetime.now()
         self.id: str = data['id']
@@ -463,13 +556,17 @@ class Message(Hashable):
             if 'edited_timestamp' in data else None
         self.mention_everyone: bool = data['mention_everyone'] \
             if 'mention_everyone' in data else None
-        self.content: str = data['content']
+        self.content: str = data['content'] if 'content' in data else ""
 
         try:
             # if the channel doesn't have a guild attribute, we handle that
             self.guild = channel.guild  # type: ignore
         except AttributeError:
-            self.guild = state._get_guild(data.get('guild_id'))
+            self.guild = state._get_guild(int(data.get('guild_id')))
+
+        if self.guild is None:
+            self.guild = Object(id=data.get('guild_id'))
+            self.guild.channels = [self.channel]
 
         try:
             ref = data['message_reference']
@@ -574,7 +671,8 @@ class Message(Hashable):
         except AttributeError:
             # It's a user here
             self.author = Member._from_message(message=self, data=member)
-            self.guild._add_member(self.author)
+            if isinstance(self.guild, Guild):
+                self.guild._add_member(self.author)
 
     def _handle_mentions(self, mentions: List[UserWithMemberPayload]) -> None:
         self.mentions = r = []
@@ -895,4 +993,4 @@ class PartialMessage(Hashable):
         """
 
         data = await self._state.http.get_message(self.channel.id, self.id)
-        return self._state.create_message(channel=self.channel, data=data)
+        return self._state.create_message(channel=self.channel, data=data, direct=False)
